@@ -23,6 +23,8 @@
 #include <glib-object.h>
 #include <gio/gio.h>
 #include <archive.h>
+#include <libgxps/gxps-version.h>
+#include <libgxps/gxps-resources.h>
 
 G_BEGIN_DECLS
 
@@ -39,9 +41,9 @@ typedef struct _GXPSArchiveClass GXPSArchiveClass;
 GType             gxps_archive_get_type       (void) G_GNUC_CONST;
 GXPSArchive      *gxps_archive_new            (GFile            *filename,
 					       GError          **error);
-
 gboolean          gxps_archive_has_entry      (GXPSArchive      *archive,
 					       const gchar      *path);
+GXPSResources    *gxps_archive_get_resources  (GXPSArchive      *archive);
 GInputStream     *gxps_archive_open           (GXPSArchive      *archive,
 					       const gchar      *path);
 gboolean          gxps_archive_read_entry     (GXPSArchive      *archive,
