@@ -286,7 +286,7 @@ gxps_images_create_from_png (GXPSArchive *zip,
 	}
 
 	stride = cairo_format_stride_for_width (format, png_width);
-	if (stride < 0) {
+	if (stride < 0 || png_height >= INT_MAX / stride) {
 		fill_png_error (error, image_uri, NULL);
 		g_object_unref (stream);
 		png_destroy_read_struct (&png, &info, NULL);
@@ -742,17 +742,12 @@ gxps_images_create_from_tiff (GXPSArchive *zip,
 	guchar     *data;
 	guchar     *p;
 
-	if (!gxps_archive_read_entry (zip, image_uri,
-				      &buffer.buffer,
-				      &buffer.buffer_len,
-				      error)) {
-		g_set_error (error,
-			     GXPS_ERROR,
-			     GXPS_ERROR_SOURCE_NOT_FOUND,
-			     "Image source %s not found in archive",
-			     image_uri);
-		return NULL;
-	}
+        if (!gxps_archive_read_entry (zip, image_uri,
+                                      &buffer.buffer,
+                                      &buffer.buffer_len,
+                                      error)) {
+                return NULL;
+        }
 
 	buffer.pos = 0;
 
@@ -925,6 +920,8 @@ gxps_images_get_image (GXPSArchive *zip,
 	if (!image) {
 		gchar *mime_type;
 
+                g_clear_error(error);
+
 		mime_type = gxps_images_guess_content_type (zip, image_uri);
 		if (g_strcmp0 (mime_type, "image/png") == 0) {
 			image = gxps_images_create_from_png (zip, image_uri, error);
