@@ -97,6 +97,8 @@ path_data_token_type_to_string (PathDataTokenType type)
         default:
                 g_assert_not_reached ();
         }
+
+        return NULL;
 }
 
 #ifdef GXPS_ENABLE_DEBUG
@@ -476,7 +478,13 @@ gxps_path_parse (const gchar *data,
                         is_rel = TRUE;
                 case 'A':
                         while (token.type == PD_TOKEN_NUMBER) {
-                                gdouble xr, yr, rx, farc, fsweep, x, y;
+                                gdouble xr, yr, x, y;
+#ifdef GXPS_ENABLE_DEBUG
+                                /* TODO: for now these variables are only used
+                                 * in debug mode.
+                                 */
+                                gdouble rx, farc, fsweep;
+#endif
 
                                 if (!path_data_get_point (&token, &xr, &yr, error))
                                         return FALSE;
@@ -487,7 +495,9 @@ gxps_path_parse (const gchar *data,
                                         path_data_parse_error (&token, PD_TOKEN_NUMBER, error);
                                         return FALSE;
                                 }
+#ifdef GXPS_ENABLE_DEBUG
                                 rx = token.number;
+#endif
 
                                 if (!path_data_iter_next (&token, error))
                                         return FALSE;
@@ -495,7 +505,9 @@ gxps_path_parse (const gchar *data,
                                         path_data_parse_error (&token, PD_TOKEN_NUMBER, error);
                                         return FALSE;
                                 }
+#ifdef GXPS_ENABLE_DEBUG
                                 farc = token.number;
+#endif
 
                                 if (!path_data_iter_next (&token, error))
                                         return FALSE;
@@ -503,7 +515,9 @@ gxps_path_parse (const gchar *data,
                                         path_data_parse_error (&token, PD_TOKEN_NUMBER, error);
                                         return FALSE;
                                 }
+#ifdef GXPS_ENABLE_DEBUG
                                 fsweep = token.number;
+#endif
 
                                 if (!path_data_iter_next (&token, error))
                                         return FALSE;
@@ -875,12 +889,14 @@ path_geometry_end_element (GMarkupParseContext  *context,
 
 		if (path->opacity_mask) {
 			gdouble x1 = 0, y1 = 0, x2 = 0, y2 = 0;
+			cairo_path_t *cairo_path;
+
 			if (path->stroke_pattern)
 				cairo_stroke_extents (path->ctx->cr, &x1, &y1, &x2, &y2);
 			else if (path->fill_pattern)
 				cairo_fill_extents (path->ctx->cr, &x1, &y1, &x2, &y2);
 
-			cairo_path_t *cairo_path = cairo_copy_path (path->ctx->cr);
+			cairo_path = cairo_copy_path (path->ctx->cr);
 			cairo_new_path (path->ctx->cr);
 			cairo_rectangle (path->ctx->cr, x1, y1, x2 - x1, y2 - y1);
 			cairo_clip (path->ctx->cr);
